#!/usr/bin/env perl

use strict;
use warnings;
use utf8;

=begin Foo

=end Foo

=cut

# No actual code here

=head1 Bar

=cut

# or here

=begin comment

    =begin indented is a comment

    =end indented is a comment

=end comment

=cut

1;
